API Reference
=============

.. toctree::
   :maxdepth: 1

   exceptions
   overlap
   momentum
   volume
   volatility
   statistic
   price_transform
   pattern
   cycle
   math_ops
   extended
   streaming
   batch
   analysis
